@@ -3,8 +3,8 @@ from dataclasses import dataclass
 from arcor2 import rest
 from arcor2.data.common import Pose
 
-from .abstract_dobot import AbstractDobot
-from .fit_common_mixin import UrlSettings
+from .abstract_dobot import AbstractDobot  # noqa:ABS101
+from .fit_common_mixin import UrlSettings  # noqa:ABS101
 
 
 @dataclass
